==> message-bus-sdk-1.0.6.7-20210517.094123-7-sources.jar: com/xforceplus/janus/message/sdk/response/PubResponse.java <==
package com.xforceplus.janus.message.sdk.response;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xforceplus.janus.message.sdk.core.AbsMbResponse;
import com.xforceplus.janus.message.sdk.core.HttpResp;
import com.xforceplus.janus.message.sdk.dto.Result;

import org.apache.http.HttpStatus;

/**
 * @author zhujie@xforceplus.com
 * @date 2021/5/10 9:41 AM
 **/
public class PubResponse extends AbsMbResponse<PubResponse> {

    private String messageId;

    public PubResponse() {
    }

    public String getMessageId() {
        return messageId;
    }

    public void setMessageId(String messageId) {
        this.messageId = messageId;
    }

    public static PubResponse transform(HttpResp httpResp) {
        PubResponse response = new PubResponse();
        response.setSuccess(true);
        if (httpResp.getHttpStatus() != HttpStatus.SC_OK) {
            response.setSuccess(false);
            response.setError(httpResp.getRespStr());
        }
        ObjectMapper mapper = new ObjectMapper();

        Result<String> result = null;
        try {
            result = mapper.readValue(httpResp.getRespStr(), new TypeReference<Result<String>>() {
            });
        } catch (JsonProcessingException e) {
            e.printStackTrace();
        }
        ;

        if (!Result.ResultCode.OK.getCode().equals(result.getCode())) {
            response.setSuccess(false);
            response.setError(result.getMessage());
        }
        response.setMessageId(result.getResult());

        return response;
    }
}

==> message-bus-sdk-1.0.6.8-20210624.035604-41-sources.jar: com/xforceplus/janus/message/sdk/response/PubResponse.java <==
package com.xforceplus.janus.message.sdk.response;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.xforceplus.janus.message.sdk.core.AbsMbResponse;
import com.xforceplus.janus.message.sdk.core.HttpResp;
import com.xforceplus.janus.message.sdk.core.Result;

import org.apache.http.HttpStatus;

/**
 * @author zhujie@xforceplus.com
 * @date 2021/5/10 9:41 AM
 **/
public class PubResponse extends AbsMbResponse<PubResponse> {

    private String messageId;

    public PubResponse() {
    }

    public String getMessageId() {
        return messageId;
    }

    public void setMessageId(String messageId) {
        this.messageId = messageId;
    }

    public static PubResponse transform(HttpResp httpResp) {
        PubResponse response = new PubResponse();
        response.setSuccess(true);
        if (httpResp.getHttpStatus() != HttpStatus.SC_OK) {
            response.setSuccess(false);
            response.setError(httpResp.getRespStr());
        }
        ObjectMapper mapper = new ObjectMapper();

        Result<String> result = null;
        try {
            result = mapper.readValue(httpResp.getRespStr(), new TypeReference<Result<String>>() {
            });
        } catch (JsonProcessingException e) {
            e.printStackTrace();
        }

        if (!Result.ResultCode.OK.getCode().equals(result.getCode())) {
            response.setSuccess(false);
            response.setError(result.getMessage());
        }
        response.setMessageId(result.getResult());

        return response;
    }
}
